Run SINDy on raw data with a sliding window approach
It returns a list of coefficients Bs containing B coefficients at each window
Matrix of raw data
Matrix of main system variable dervatives; if NULL, it estimates with finite differences from xs
Sample interval, if data continuously sampled; default = 1
Matrix of features; if not supplied, assumes polynomial features of order 3
Threshold to use for iterated least squares sparsification (Brunton et al.)
Number of iterations to conduct the least-square threshold sparsification; default = 10
The function will compute a goodness of fit if supplied with an expected coefficient matrix B; default = NULL
Size of window to segment raw data as separate time series; defaults to deciles
Step sizes across windows, permitting overlap; defaults to deciles
Rick Dale and Harish S. Bhat
A convenience function for extracting a list of coefficients on segments of a time series. This facilitates using SINDy output as source of descriptive measures of dynamics.
Dale, R. and Bhat, H. S. (in press). Equations of mind: data science for inferring nonlinear dynamics of socio-cognitive systems. Cognitive Systems Research.